==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfSectionCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSectionCollection(IEnumerable):
    """
    The collection of the sections.
    """

    def get_Item(self, index: int) -> 'PdfSection':
        """
        Gets the section at the specified index.
        """
        GetDllLibPdf().PdfSectionCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSectionCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSectionCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else PdfSection(intPtr)
        return ret

    @property
    def Count(self) -> int:
        """
        Gets the count.
        """
        GetDllLibPdf().PdfSectionCollection_get_Count.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionCollection_get_Count.restype = c_int
        ret = GetDllLibPdf().PdfSectionCollection_get_Count(self.Ptr)
        return ret

    @dispatch
    def Add(self, pageSettings: PdfPageSettings) -> PdfSection:
        """
        Creates a section and adds it to the collection.
        Returns the created section object.
        """
        intPtrpageSettings: c_void_p = pageSettings.Ptr
        GetDllLibPdf().PdfSectionCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionCollection_Add.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSectionCollection_Add(self.Ptr, intPtrpageSettings)
        ret = None if intPtr == None else PdfSection(intPtr)
        return ret

    @dispatch
    def Add(self) -> PdfSection:
        """
        Adds a section to the collection.
        """
        GetDllLibPdf().PdfSectionCollection_Add1.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionCollection_Add1.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSectionCollection_Add1(self.Ptr)
        ret = None if intPtr == None else PdfSection(intPtr)
        return ret

    def IndexOf(self, section: 'PdfSection') -> int:
        """
        Determines the index of the section.
        Returns the index of the section.
        """
        intPtrsection: c_void_p = section.Ptr
        GetDllLibPdf().PdfSectionCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionCollection_IndexOf.restype = c_int
        ret = GetDllLibPdf().PdfSectionCollection_IndexOf(self.Ptr, intPtrsection)
        return ret

    def Insert(self, index: int, section: 'PdfSection'):
        """
        Inserts the section at the specified index.
        """
        intPtrsection: c_void_p = section.Ptr
        GetDllLibPdf().PdfSectionCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().PdfSectionCollection_Insert(self.Ptr, index, intPtrsection)

    def Contains(self, section: 'PdfSection') -> bool:
        """
        Checks whether the collection contains the section.
        Returns True if the section belongs to the collection, False otherwise.
        """
        intPtrsection: c_void_p = section.Ptr
        GetDllLibPdf().PdfSectionCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionCollection_Contains.restype = c_bool
        ret = GetDllLibPdf().PdfSectionCollection_Contains(self.Ptr, intPtrsection)
        return ret

    def GetEnumerator(self) -> 'IEnumerator':
        """
        Gets the enumerator.
        """
        GetDllLibPdf().PdfSectionCollection_GetEnumerator.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionCollection_GetEnumerator.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSectionCollection_GetEnumerator(self.Ptr)
        ret = None if intPtr == None else IEnumerator(intPtr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfSectionCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSectionCollection(IEnumerable):
    """
    The collection of the sections.
    """

    def get_Item(self, index: int) -> 'PdfSection':
        """
        Gets the section at the specified index.
        """
        GetDllLibPdf().PdfSectionCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSectionCollection_get_Item.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionCollection_get_Item,self.Ptr, index)
        ret = None if intPtr == None else PdfSection(intPtr)
        return ret

    @property
    def Count(self) -> int:
        """
        Gets the count.
        """
        GetDllLibPdf().PdfSectionCollection_get_Count.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionCollection_get_Count.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfSectionCollection_get_Count,self.Ptr)
        return ret

    @dispatch
    def Add(self, pageSettings: PdfPageSettings) -> PdfSection:
        """
        Creates a section and adds it to the collection.
        Returns the created section object.
        """
        intPtrpageSettings: c_void_p = pageSettings.Ptr
        GetDllLibPdf().PdfSectionCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionCollection_Add.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionCollection_Add,self.Ptr, intPtrpageSettings)
        ret = None if intPtr == None else PdfSection(intPtr)
        return ret

    @dispatch
    def Add(self) -> PdfSection:
        """
        Adds a section to the collection.
        """
        GetDllLibPdf().PdfSectionCollection_Add1.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionCollection_Add1.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionCollection_Add1,self.Ptr)
        ret = None if intPtr == None else PdfSection(intPtr)
        return ret

    def IndexOf(self, section: 'PdfSection') -> int:
        """
        Determines the index of the section.
        Returns the index of the section.
        """
        intPtrsection: c_void_p = section.Ptr
        GetDllLibPdf().PdfSectionCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionCollection_IndexOf.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfSectionCollection_IndexOf,self.Ptr, intPtrsection)
        return ret

    def Insert(self, index: int, section: 'PdfSection'):
        """
        Inserts the section at the specified index.
        """
        intPtrsection: c_void_p = section.Ptr
        GetDllLibPdf().PdfSectionCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        CallCFunction(GetDllLibPdf().PdfSectionCollection_Insert,self.Ptr, index, intPtrsection)

    def Contains(self, section: 'PdfSection') -> bool:
        """
        Checks whether the collection contains the section.
        Returns True if the section belongs to the collection, False otherwise.
        """
        intPtrsection: c_void_p = section.Ptr
        GetDllLibPdf().PdfSectionCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSectionCollection_Contains.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfSectionCollection_Contains,self.Ptr, intPtrsection)
        return ret

    def GetEnumerator(self) -> 'IEnumerator':
        """
        Gets the enumerator.
        """
        GetDllLibPdf().PdfSectionCollection_GetEnumerator.argtypes = [c_void_p]
        GetDllLibPdf().PdfSectionCollection_GetEnumerator.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfSectionCollection_GetEnumerator,self.Ptr)
        ret = None if intPtr == None else IEnumerator(intPtr)
        return ret
